function [ret,phan]=Aqual2_loadNifti(filename,verbose)
ret=0;
minFOV=175;
% in mm figure that nobody will be off that much and still cover the phantom
% OR that we don't want to try to analyze something that broken
nominalFOV=200;
if ~exist('verbose','var')
        verbose=0;
end
if  verbose>1
   disp('loading image data');
end
try
    if ~exist('img_idx','var'), img_idx = []; end
   if ~exist('old_RGB','var'), old_RGB = 0; end
    %    we don't use the main load_nii entry point since we need to manage
    %   the orientation qform very explicitly.
    [phan.hdr,phan.filetype,phan.fileprefix,phan.machine] = load_nii_hdr(filename);
    [phan.img,phan.hdr] = ...
        load_nii_img(phan.hdr,phan.filetype,phan.fileprefix,phan.machine,img_idx,old_RGB);
catch
    estring=sprintf('failed to load data for %s',filename);
    Aqual2_writeFailureLog(filename,estring);
    ret=1;
    return;
end
if verbose >1 
    disp('done loading image data -- examining geometric configuration');
end

if ((phan.hdr.hist.qform_code~=1)  && (phan.hdr.hist.qform_code~=-1))
    estring=sprintf('qform code for %s is not +/-1',filename);
    Aqual2_writeFailureLog(filename,estring);
    ret=1;
    return;
end

fov=phan.hdr.dime.pixdim(2:4).*phan.hdr.dime.dim(2:4);
if(sum (fov >= [minFOV,minFOV,minFOV]) <3 )
    estring=sprintf('FOV is too small in image %s',filename);
    Aqual2_writeFailureLog(filename,estring);
    ret=1;
    return;
end

if(sum (fov >= [nominalFOV,nominalFOV,nominalFOV]) <3 )
    estring=sprintf('Note:FOV is small than nominal (%d mm)  in image %s',nominalFOV,filename);
    Aqual2_writeFailureLog(filename,estring);
    disp(estring);
end
clear fov;

try
    b = phan.hdr.hist.quatern_b;
    c = phan.hdr.hist.quatern_c;
    d = phan.hdr.hist.quatern_d;
    a = sqrt(1.0-(b*b+c*c+d*d));
    a=real(a);
    qfac = phan.hdr.dime.pixdim(1);
    i = phan.hdr.dime.pixdim(2);
    j = phan.hdr.dime.pixdim(3);
    k = qfac * phan.hdr.dime.pixdim(4);

    R = [a*a+b*b-c*c-d*d     2*b*c-2*a*d        2*b*d+2*a*c
        2*b*c+2*a*d         a*a+c*c-b*b-d*d    2*c*d-2*a*b
        2*b*d-2*a*c         2*c*d+2*a*b        a*a+d*d-c*c-b*b];

    R = R * diag([i j k]);

    T = [phan.hdr.hist.qoffset_x
        phan.hdr.hist.qoffset_y
        phan.hdr.hist.qoffset_z];
    phan.RAS=[R T];
    phan.RAS(4,:)=[0 0 0 1 ];
catch
    estring=sprintf('very unexpected error in calculating vox-to-RAS xform');
    Aqual2_writeFailureLog(filename,estring);
    ret=1;
    return;
end
if verbose>1 
    disp('done examining geometric configuration');
end