function [SNR,Signal,Noise,DarkRegionSNR] = CalculateSNRFromSphere ...
    ( Image, Mask, NumberOfErosions, EnableDark )
% function [SNR,Signal,Noise,DarkRegionSNR] = CalculateSNRFromSphere ( Image, Mask, NumberOfErosions )
%  
% Compute least squares fit to signal to subtract, then compute noise. Fit
% is with a 2nd order polynomial.
% Image is the volume to calculate over, Mask are the voxels to
% use, eroded NumberOfErosions (default 9) times by a 3x3x3
% Structuring element.
% SNR, Signal and Noise are aptly named
% DarkRegionSNR is a two element array: (1)=signal, (2)=noise
% defined over an arbitrary part of the image; moreover the
% arbitrary part of the image is agnostic of image size 
% which means it can easily throw an Index exceeds matrix
% dimensions error 
% DarkRegionSNR is only calculated EnableDark passed
  
  
  if ~exist ( 'NumberOfErosions', 'var' )
    NumberOfErosions = 9;
  end
  
% Erode the mask
  [sx sy sz] = meshgrid ( -1:1, -1:1, -1:1 );
  st = sqrt ( sx.^2 + sy.^2 + sz.^2 ) <= 1;
  for dd = 1:NumberOfErosions
    Mask = imerode ( Mask, st );
  end
  
  MaskIdx = find ( Mask );
  [x y z] = ind2sub ( size ( Image ), MaskIdx );
  o = ones ( length ( MaskIdx ), 1 );
  X = [o x y z x.*x x.*y x.*z y.*y y.*z z.*z];
  Y = Image ( MaskIdx );

  % solution to least squares problem to fit signal 
  fitCoeffs=X\Y; 
  smoothfit=X*fitCoeffs;

  NoiseData = Image(MaskIdx) - smoothfit;
  
  % figure ( 1 );  hist ( NoiseData, 100 ); title ( 'SNR Sphere noise histogram' );

  Noise = std ( NoiseData );
  Signal = sum ( Image( MaskIdx ) ) / length ( MaskIdx );
  SNR = Signal / Noise;
  % disp ( sprintf ( 'Signal: %f Noise: %f SNR: %f', Signal, Noise, SNR ) );
  
  % Just make a mask
  if(exist ( 'EnableDark', 'var' ))
    Mask = Mask*0;
    z = 20:size(Mask,3)-20;
    Mask(20:50,20:50,z) = 1;
    Mask(215:235,20:50,z) = 1;
    Mask(20:50,215:235,z) = 1;
    Mask(215:235,215:235,z) = 1;
    idx = find ( Mask );
    DarkRegionSNR(1) = mean ( Image(idx) );
    DarkRegionSNR(2) = std ( Image ( idx ) );
    % disp ( sprintf ( 'Dark region Mean: %f Std: %f', mean ( Image(idx) ), std ( Image ( idx ) ) ) );
    % figure ( 2 );  hist ( Image(idx), 100 ); title ( 'Dark region histogram' );
  end
  
  
  
  return
  TempArray = zeros(size(VolArray));
  VolTemp = double(VolArray);
  NoiseData = zeros(size(smoothfit));
  [dim1,dim2,dim3] = size(mask);
  index = 1;

  for ind = 1:Nsize
    ind1 = indexmap(ind,1); ind2 = indexmap(ind,2); ind3 = indexmap(ind,3);
    TempArray(ind1,ind2,ind3) = smoothfit(ind);
    NoiseData(ind) = VolTemp(ind1,ind2,ind3) - smoothfit(ind);
  end

 center=round(mean(indexmap))%center of region of interest
 figure;
 ind=1:256;
 plot(ind,VolTemp(ind,center(2),center(3)));
 hold on
 plot(ind,TempArray(ind,center(2),center(3)),'r');


% bins=-20:.25:25;
% hist(NoiseData,bins)


disp('Noise is ');
Noise=std(NoiseData)

  
  
Nsize=sum(sum(sum(mask))); %Number of pixels in region of interest
indexmap=zeros(Nsize,3);
[dim1,dim2,dim3]=size(mask);
index=1;
X=zeros(Nsize,10);%10 is the number of basis functions. This is for Least squares fit
Y=zeros(Nsize,1);%'y' matrix for least squares problem.
for ind1=1:dim1 %assign region of interest and subscripts to VolInt cell array
    for ind2=1:dim2
        for ind3=1:dim3
            if mask(ind1,ind2,ind3)==1 %set up Least Squares arrays
                X(index,:)=[1,ind1,ind2,ind3,ind1*ind1,ind1*ind2,ind1*ind3,ind2*ind2,ind2*ind3,ind3*ind3];%array of basis functions
                Y(index,1)=VolArray(ind1,ind2,ind3);
                indexmap(index,:)=[ind1,ind2,ind3]; %set up index map for future use.
                index=index+1;
            end
        end
    end
end


fitCoeffs=X\Y; %solution to least squares problem to fit signal         
smoothfit=X*fitCoeffs;%smoothed fit


TempArray=zeros(size(VolArray));
VolTemp=double(VolArray);
NoiseData=zeros(size(smoothfit));
[dim1,dim2,dim3]=size(mask);
index=1;


for ind=1:Nsize
    ind1=indexmap(ind,1);ind2=indexmap(ind,2);ind3=indexmap(ind,3);
    TempArray(ind1,ind2,ind3)=smoothfit(ind);
    NoiseData(ind)=VolTemp(ind1,ind2,ind3)-smoothfit(ind);
end

 center=round(mean(indexmap))%center of region of interest
 figure;
 ind=1:256;
 plot(ind,VolTemp(ind,center(2),center(3)));
 hold on
 plot(ind,TempArray(ind,center(2),center(3)),'r');


% bins=-20:.25:25;
% hist(NoiseData,bins)


disp('Noise is ');
Noise=std(NoiseData)
