function CompareSpheres ( A, B, Results )
% CompareSpheres ( A, B, [Results] )
%
% Compare different sphere measurements between the two sphere
% datasets.  Results is the output of WarpPhantom and gives the
% warping taking VoxelCOM in B into A.
    
% First measure is RMS of the distance between sphere pairs
SphereCount = length ( A.Spheres );
SphereDistances = zeros ( 0.5 * SphereCount * (SphereCount - 1), 1 );
WarpedSphereDistances = zeros ( 0.5 * SphereCount * (SphereCount - 1), 1 );

DoWarp = 0;
if exist ( 'Results', 'var' )
  DoWarp = 1;
  VoxelToRASTForm = maketform ( 'affine', B.VoxelToRASTransform' );
end

Count = 1;
for ii = 1:SphereCount
  for jj = ii+1:SphereCount
    ADistance = sqrt ( sum ( ( A.Spheres(ii).RASCOM - A.Spheres(jj).RASCOM ).^2 ) );
    BDistance = sqrt ( sum ( ( B.Spheres(ii).RASCOM - B.Spheres(jj).RASCOM ).^2 ) );
    SphereDistances(Count) = abs ( ADistance - BDistance );
    
    Count = Count + 1;
  end
end

disp ( 'Sphere Distances' );
disp ( sprintf ( '\tMean: %f Max: %f Min: %f', ...
		 mean ( SphereDistances ), ...
		 max ( SphereDistances ), ...
		 min ( SphereDistances ) ) );
    
% Idx = find ( SphereDistances > 0 );
hist ( SphereDistances, 30 );

  
