function Im = LoadAnalyzeImage ( FileName )
% Load an Analyze image, with the correct spacing
global noPermute;  
% Figure out the base name
  [path, name, ext, version] = fileparts ( FileName );
  
  BaseName = fullfile ( path, name );
  
  HeaderFileName = sprintf ( '%s.hdr', BaseName );
  ImageFileName = sprintf ( '%s.img', BaseName );
  
  % Get the dimensions
  fid = fopen ( HeaderFileName, 'r', 'n' );  % try to read in native byte order
  if fid == -1
    error ( sprintf ( 'Could not open file: %s', HeaderFileName ) );
  end
  endian=fread(fid,1,'int16');
  if(endian(1)~= 348)
    if(endian(1) ==352)
      warning(['image seems to be NIFTI?  Cannot read NIFTI --' ...
	       ' this will probably not work']);
    else
      warning('wrong header size -- possibly wrong endian');
    end 
  end
  fseek(fid,40+30,'bof');
  datatypecode=fread(fid,1,'short');
  switch datatypecode 
   case {1,32,64,128}
    warning('datatype not supported');
    % nb 1 exclude becase bit fields have to padded to byte boundaries
    % exclude other "bigger" data types
   case 2
    datatype='uchar';
    datasize=1;
    dataString='AVW_UNSIGNED_CHAR';
   case 4 
    datatype='short';
    datasize=2;
    dataString='AVW_SIGNED_SHORT';
   case 8
    datatype='int32';
    datasize=4;
    dataString='AVW_SIGNED_INT';
   case 16
    datatype='float';
    datasize=4;
    dataString='AVW_FLOAT';
  end
  
  fseek ( fid, 40,'bof' );
  dim = fread ( fid, 8, 'short' );
    
  x = dim(2);
  y = dim(3);
  z = dim(4);
  
  fseek(fid,40+36,'bof');
  voxSize=fread(fid,8,'float');
  vx=voxSize(2);
  vy=voxSize(3);
  vz=voxSize(4);
  
  
  fclose ( fid );
  fid = fopen ( ImageFileName, 'r', 'n' );
    % native byte ordering 
   if fid == -1
    error ( sprintf ( 'Could not open file: %s', ImageFileName ) );
  end
  fseek ( fid, 0, 'eof' );
  s = ftell ( fid );
  headersize = s - x * y * z * datasize;
  fseek ( fid, headersize, 'bof' );
  %Image = reshape ( fread ( fid, 'short' ), x, y, z );
  
  Image = reshape ( fread ( fid, x*y*z, datatype ), x, y, z );
  % Need to transpose each slice
  %for ZSlice = 1:z
  %if( ~exist('noPermute','var'))  % global at the beginning creates
  %noPermute if not present so exist check isn't what you want
  % what you want is for the parent to set  global noPermute; noPermute=1;
  % before calling this in order to specify no permutation
  % if noPermute=[] or noPermute is not defined globally in the base stack
  % space then permutation will be done.
   if(isempty(noPermute))
    Image=permute(Image,[2,1,3]);
  end
    %Image(:,:,ZSlice) = Image(:,:,ZSlice)';
   % Image
  %end
  Im=struct('Image',0,'DataType',dataString,'Width',x,'Height',y,'Depth',z,'NumVols',1,'VoxelWidth',vx,'VoxelHeight',vy,'VoxelDepth',vz);    
  Im.Image=Image;
  
  
  fclose ( fid );
  return
  
