function [I, Headers] = LoadDICOMSeriesFast ( Pattern, CustomDictionary )
% [I, Headers] = LoadDICOMSeriesFast ( Pattern, CustomDictionary )
%
% Read a dicom series quickly, without reading every header

  if ~exist ( 'CustomDictionary', 'var' )
    CustomDictionary = 'dicom-dict.mat';
  end
  
  % Find the files
  FileList = dir ( Pattern );
  Count = length ( FileList );
  
  [Directory, name, ext, version] = fileparts ( Pattern );
  Directory = [Directory filesep];
  
  % Read the first one to get the size
  Header = dicominfo ( [Directory FileList(1).name], 'dictionary', CustomDictionary );
  Image = dicomread ( Header );
  Headers = Header;
  
  [r, c] = size ( Image );
  I = zeros ( r, c, Count );
  Endian = 'ieee-le';
  
  for SliceIdx = 1:Count,
    FN = sprintf ( '%sImage%04d.dcm', Directory, SliceIdx );

    fid = fopen ( FN, 'rb', Endian );
    fseek ( fid, -r*c*2, 'eof' );
    t = fread ( fid, [r c], 'int16' )';
    fclose ( fid );
    
    % Header = dicominfo ( FN );
    % Image = dicomread ( Header );
    I(:,:,SliceIdx) = t;
    % Headers(SliceIdx) = Header;
    if SliceIdx < 3
      disp ( sprintf ( 'Reading slice %d: %s', SliceIdx, FN ) );
      Headers(SliceIdx) = dicominfo ( FN, 'dictionary', CustomDictionary );
      Header = Headers(SliceIdx);
      Image = dicomread ( Header );
      TT = double(Image(:)) - double(t(:));
      TT = sqrt ( mean ( TT.^2 ) );
      if TT ~= 0
        error ( sprintf ( 'Failed to read images, RMS error is %f', TT ) );
      end
      % figure ( 2*SliceIdx ); imagesc ( Image );
      % figure ( 2* SliceIdx + 1 ) ; imagesc ( t );
    end
  end

  
  % Make sure we are consistent!
  XYZ = CoordinateSystems ( Headers, 'XYZ' );
  IPP = [Headers.ImagePositionPatient]';
  Len = length ( Headers );
  o = ones ( Len, 1 );
  t = 1:Len;
  t = t';
  Locs = XYZ * [o o t o]';
  Locs = Locs';
  Locs = Locs(:,1:3);
  DD = Locs - IPP;
  DD = sqrt ( sum ( DD.^2, 2 ) );
  if max(DD) > 0.001
    disp ( 'LoadDICOMSeriesFast: flipping slices' );
    FN = sprintf ( '%s/Image%04d.dcm', Directory, Count );
    Headers(1)  = dicominfo ( FN, 'dictionary', CustomDictionary );
    FN = sprintf ( '%s/Image%04d.dcm', Directory, Count-1 );
    Headers(2)  = dicominfo ( FN, 'dictionary', CustomDictionary );
    I = I(:,:,Count:-1:1);
  end
  return
% [Image, Headers] = LoadDicomSeries ( '/home/blezek/src/MION/ADData/2003-01-27-DualEcho3T/SE1/*.dcm' );