function W = SphericalHarmonics ( BaselinePoints, CalibrationPoints, Harmonics )
% W = SphericalHarmonics ( BaselinePoints, CalibrationPoints )
% Creates a structure that can be used with SphericalHarmonicsValue
% to warp a point in CalibrationPoints space into BaselinePoints space.
% BaselinePoints and CalibrationPoints must be 3xN matrices.
% See also SphericalHarmonicsValue.
  
  
  KRange = 1:10;
  if exist ( 'Harmonics', 'var' )
    KRange = Harmonics;
  end
  
  [D, N] = size ( BaselinePoints );
  if D ~= 3
    error ( 'SphericalHarmonics requires 3D data' );
  end

  
  try
    load GradWarpCoefficients.mat
  catch
    % Generate them from 1-10
    for kk = 1:10
      hx = sphericalHarmonics ( kk, 1, 'c', 'cart' );
      hx = strrep ( char ( hx ), '*', '.*' );
      hx = strrep ( char ( hx ), '^', '.^' );
      
      hy = sphericalHarmonics ( kk, 1, 's', 'cart' );
      hy = strrep ( char ( hy ), '*', '.*' );
      hy = strrep ( char ( hy ), '^', '.^' );
      
      hz = sphericalHarmonics ( kk, 0, 'c', 'cart' );
      hz = strrep ( char ( hz ), '*', '.*' );
      hz = strrep ( char ( hz ), '^', '.^' );
      
      Hx{kk} = hx;
      Hy{kk} = hy;
      Hz{kk} = hz;
    end
    save GradWarpCoefficients Hx Hy Hz
  end

  idx = 1;
  Ax = zeros ( N, length ( KRange ) );
  Ay = zeros ( N, length ( KRange ) );
  Az = zeros ( N, length ( KRange ) );

  e = BaselinePoints - CalibrationPoints;

  ex = e(1,:)';
  ey = e(2,:)';
  ez = e(3,:)';

  x = BaselinePoints(1,:)';
  y = BaselinePoints(2,:)';
  z = BaselinePoints(3,:)';

  idx = 1;
  for kk = KRange
    Ax(:,idx) = eval ( Hx{kk} );
    Ay(:,idx) = imag ( eval ( Hy{kk} ) );
    Az(:,idx) = eval ( Hz{kk} );
    idx = idx + 1;
  end

  sx = Ax \ ex;
  sy = Ay \ ey;
  sz = Az \ ez;
  
  W = struct([]);
  W(1).sx = sx;
  W.sy = sy;
  W.sz = sz;
  W.Coefficients = KRange;
  

