
Directory = '/local/MION/CalibrationData/2003-05-28-ScalingScan/DICOM'

try
  load ScalingExam20030528Calibration;
catch  
  clear SphereData;

  Exam = 198;
  for SeriesID = 10:18
    [Image, Headers] = LoadDICOMSeries ( [Directory '/198/' int2str(SeriesID) '/*.dcm'], 0 );
    Spheres = SegmentSpheres ( Headers(1), Image );
    
    Spheres.Directory = Directory;
    Spheres.Exam = Exam;
    Spheres.SeriesID = SeriesID;
    command = ['SphereData', int2str(SeriesID), ' = Spheres;'];
    eval ( command );
    command = ['SphereData(', int2str(SeriesID), ') = Spheres;'];
    eval ( command );
  end
  for SeriesID = 10:18
    if SeriesID ~= 10
      SphereData(SeriesID) = ReorderSpheres ( SphereData(10), SphereData(SeriesID) );
    end
  end

  save ScalingExam20030528Calibration SphereData*
end


% First part of validation is to make sure that the sphere centers
% in voxel space map within a reasonable error to the sphere
% centers in the baseline scan

Baseline = SphereData ( 10 );
Parameters = WarpDefaults;


disp ( 'First test: determine the RMS error in the sphere COM (Voxel) using the warp.\n' );
for row = 10:18
  Calibration = SphereData ( row );
  
  % Load the series
  % [Image, Headers] = LoadDICOMSeries ( [Calibration.Directory '/' int2str(Calibration.Exam) '/' int2str(Calibration.SeriesID) '/*.dcm'], 0 );
  
  
  % Skip the warp
  Parameters.DoWarp = 0;
  [Foo, Results] = WarpPhantom ( [], Calibration, Baseline, Calibration, Parameters );
  
  BaselineSpheresCOM = [Baseline.Spheres.VoxelCOM];
  CalibrationSpheresCOM = [Calibration.Spheres.VoxelCOM];
  
  ODelta = BaselineSpheresCOM - CalibrationSpheresCOM;
  ODeltaM = sqrt ( sum ( ODelta.^2 ) );
  ORMS = sqrt ( mean ( sum ( ODelta.^2 ) ) );
  
  Delta = BaselineSpheresCOM' - tforminv ( CalibrationSpheresCOM', Results.Warp );
  Delta = CalibrationSpheresCOM' - tforminv ( BaselineSpheresCOM', Results.Warp );
  Delta = Delta';
  DeltaM = sqrt ( sum ( Delta.^2 ) );
  RMS = sqrt ( mean ( sum ( Delta.^2 ) ) );
  
  disp ( sprintf ( 'Series: %d Original RMS: %f RMSE: %f', row, ORMS, RMS ) );
end


disp ( 'Second test: do the warp, and determine how far away the spheres are from the baseline scan' );
for row = 10:18
  Calibration = SphereData ( row );
  
  % Load the series
  [Image, Headers] = LoadDICOMSeries ( [Calibration.Directory '/' int2str(Calibration.Exam) '/' int2str(Calibration.SeriesID) '/*.dcm'], 0 );
  Parameters = WarpDefaults;
  Parameters.CalculateVolume = 0;
  Parameters.InterpolationMethod = 'cubic';
  [NewImage, Results] = WarpPhantom ( Image, Calibration, Baseline, Calibration, Parameters );

  % Find the spheres
  NewSpheres = SegmentSpheres ( Headers(1), NewImage );
  NewSpheres = ReorderSpheres ( Baseline, NewSpheres );
  
  BaselineSpheresCOM = [Baseline.Spheres.VoxelCOM];
  CorrectedSpheresCOM = [NewSpheres.Spheres.VoxelCOM];
  Delta = BaselineSpheresCOM - CorrectedSpheresCOM;
  DeltaM = sqrt ( sum ( Delta.^2 ) );
  RMS = sqrt ( mean ( sum ( Delta.^2 ) ) );
  
  disp ( sprintf ( 'Series: %d RMSE: %f', row, RMS ) );

end





% ProcessPhantom
FilenameBase = ['Reports/Report-' datestr(now,29) '-Scaling-Exam20030528'];
fid = SafeFOpen ( [FilenameBase '.txt'], 'w' );
fprintf ( fid, 'Correcting data to calibration series 1.\n' );
fprintf ( fid, 'Width 6 windowed sinc, TPS.\n' );
fprintf ( fid, '\tOriginal\t\tWarped\n' );
fprintf ( fid, 'Series\tOtsu\tArea\tOtsu\tArea\n' );

R = [];

% Warp parameters
Parameters = WarpDefaults;
Parameters.SliceNumber = 50;
Parameters.SliceNumber = -1;
Parameters.InterpolationMethod = CreateHannSincKernel ( 6.0, 1000.0 );
% Parameters.InterpolationMethod = 'cubic';
% Parameters.InterpolationMethod = 'linear';
Parameters.PadMethod = 'replicate';
Parameters.SplineType = 'tps';
for row = 1:9
  disp ( sprintf ( 'Working on %d', row ) );
  Patient = VolumeData ( row );
  Baseline = SphereData ( 10 );
  Calibration = SphereData ( row+9 );
  [Image, Headers] = LoadDICOMSeries ( [Directory '/' int2str(Patient.Exam) '/' int2str(Patient.SeriesID) '/*.dcm'], 0 );
  try
    [NewImage, Results] = WarpPhantom ( Image, Patient, Baseline, Calibration, Parameters );
    disp ( sprintf ( '\tWarped %d in %f seconds', row, Results.WarpTime ) );
    
    fprintf ( fid, '%d\t%f\t%f\t%f\t%f\t\n', ...
              Patient.SeriesID, ...
              Results.OriginalOtsuCount, ...
              Results.OriginalImageContourArea, ...
              Results.WarpedOtsuCount, ...
              Results.WarpedImageContourArea ...
              );
    R = [R Results];
  catch
    lasterr
  end  
end

fclose ( fid );

S = 1:length(R);
Original = [R.OriginalImageContourArea];
Warped = [R.WarpedImageContourArea];


figure ( 1 ); clf;
plot ( S, Original/Original(1), 'b+', S, Warped/Original(1), 'r+' );
legend ( 'Original', 'Corrected' );
saveas ( 1, [FilenameBase '.png'] );

