function varargout = selectDICOMfiles(selectmode,filtr,directory)
% varargout = selectDICOMfiles(selectmode)
% allows selection of either a directory, or multiple files within a
% single directory, depending on the value of selectmode.
% selectmode = 'file' , or 'dir' .. see below for details.
% selectmode = 'dicom' is NOT YET IMPLEMENTED, but it will read the DICOM
% headers of the pwd, and display a list of dicom series to choose from.
% USAGE:
% [filenames,pathname] = selectDICOMfiles(selectmode)
% INPUTS:
% selectmode - 'dicom'  (default if missing)
%              'dir'
%              'dicomseries'
%              'file'
% USAGE:
% [filenames,pathname] = selectDICOMfiles('dicom')
% OUTPUT:
%        filenames will be a struct as returned by the DIR function
%        pathname is always a char.
%
% [pathname] = selectDICOMfiles('dir')
%        pathname is always a char.
%
% [filenames,pathname] = selectDICOMfiles('file')
%  KNOWN BUG: when ctrl+a is used to select all files, the filelist comes back empty.
%  opens a multiple file select dialog
%     OUTPUT:
%        filename - if 1 file is selected, filename is a char,
%                   if multiple files are selected (hold down ctrl or
%                   shift), filename is a cell array of char file names.
%        pathname is always a char.
% 
if ~exist('selectmode','var')
    selectmode = 'dicom';
end
if ~exist('filtr','var')
    filtr = '*.dcm';
end
if iscell(filtr)
    foo = char(filtr);
    clear filtr;
    filtr = foo;
    clear foo;
end
switch(lower(selectmode))
    case 'file'
        [filename, pathname, filterindex] = uigetfile( ...
            {'*.dcm','DICOM (*.dcm)'; ...
            '*.*',  'All Files (*.*)'}, ...
            'Select file(s)','MultiSelect','on');
        varargout = {filename,pathname};
    case 'dir'
        pathname = uigetdir(pwd, 'Select directory containing DICOM series');
        varargout = {pathname};
    case 'dicomseries'
        % this mode will create a listbox of dicom series to select from
        % will use dicominfo to determine complete series names in each directory.
                  pathname = uigetdir(pwd, 'Select directory containing DICOM series');
                  fnames = findfiles('dcm',pathname);
            for ii = 1:length(fnames)
                [pth,nam,ext,ver] = fileparts(fnames{ii});
                header = dicominfo(fnames{ii});
                SeriesInstanceUID = header.SeriesInstanceUID;
                StudyInstanceUID = header.StudyInstanceUID;
                PatientID = header.PatientID;
                SeriesNumber = header.SeriesNumber;
            end
          error('not yet implemented')
    case 'dicom'
        % this mode will create a listbox of dicom files to select from.
        % dicom files are defined as files that match the search filtr.
        % and are all contained in the directory.  
        % Currently this is the default mode.  
        if ~(exist('directory','var') & exist('directory','dir'))
            directory = uigetdir(pwd,'Select DICOM directory');
        end
        %files = dir([directory,filesep,filtr]);
    otherwise
        error('unknown input')
end
try
            FileList = get_files([directory,filesep,filtr],'dir');
        catch
            disp(['apparently no ',filtr,' files in ',directory])
            button = questdlg(['No ',filtr,' files found in ',directory,'. What to do?'],'title','change dir',['change (',filtr,') filter'],'change dir');
            %        error
            switch(lower(button))
                case 'change dir'
                    [FileList,directory] = selectDICOMfiles(selectmode,filtr,directory);
                case ['change (',filtr,') filter'];
                    %                    filtr = inputdlg
                    prompt={'Enter the new search filter:'};
                    name='Input Search Filter';
                    numlines=1;
                    defaultanswer={'*.*'};
                    filtr = inputdlg(prompt,name,numlines,defaultanswer);
                    [FileList] = selectDICOMfiles(selectmode,filtr,directory);
            end
        end
        varargout = {FileList,directory};
end
